# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/clients/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/clients/address.proto\x12#pro.omni.oms.api.v1.clients.address\x1a\x11\x63ommon/base.proto"?\n\x0fTerritoryMatrix\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05"\xbf\x02\n\x07\x41\x64\x64ress\x12\x12\n\ncountry_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0ctype_address\x18\x04 \x01(\t\x12\x0e\n\x06street\x18\x05 \x01(\t\x12\x0f\n\x07street2\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\t\x12\x0b\n\x03lng\x18\x08 \x01(\t\x12\x10\n\x08zip_code\x18\t \x01(\t\x12P\n\x12territory_matrixes\x18\n \x03(\x0b\x32\x34.pro.omni.oms.api.v1.clients.address.TerritoryMatrix\x12\x0e\n\x06\x61\x63tive\x18\x0b \x01(\x08\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc6\x02\n\x14\x41\x64\x64ressCreateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x12\n\ncountry_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0ctype_address\x18\x05 \x01(\t\x12\x0e\n\x06street\x18\x06 \x01(\t\x12\x0f\n\x07street2\x18\x07 \x01(\t\x12\x0b\n\x03lat\x18\x08 \x01(\t\x12\x0b\n\x03lng\x18\t \x01(\t\x12\x10\n\x08zip_code\x18\n \x01(\t\x12P\n\x12territory_matrixes\x18\x0b \x03(\x0b\x32\x34.pro.omni.oms.api.v1.clients.address.TerritoryMatrix\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n\x15\x41\x64\x64ressCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address"\xa0\x01\n\x14\x41\x64\x64ressUpdateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n\x15\x41\x64\x64ressUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address"o\n\x14\x41\x64\x64ressDeleteRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x41\x64\x64ressDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xb3\x03\n\x10\x41\x64\x64ressesService\x12\x88\x01\n\rAddressCreate\x12\x39.pro.omni.oms.api.v1.clients.address.AddressCreateRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressCreateResponse"\x00\x12\x88\x01\n\rAddressUpdate\x12\x39.pro.omni.oms.api.v1.clients.address.AddressUpdateRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressUpdateResponse"\x00\x12\x88\x01\n\rAddressDelete\x12\x39.pro.omni.oms.api.v1.clients.address.AddressDeleteRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.clients.address_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _TERRITORYMATRIX._serialized_start = 84
    _TERRITORYMATRIX._serialized_end = 147
    _ADDRESS._serialized_start = 150
    _ADDRESS._serialized_end = 469
    _ADDRESSCREATEREQUEST._serialized_start = 472
    _ADDRESSCREATEREQUEST._serialized_end = 798
    _ADDRESSCREATERESPONSE._serialized_start = 801
    _ADDRESSCREATERESPONSE._serialized_end = 962
    _ADDRESSUPDATEREQUEST._serialized_start = 965
    _ADDRESSUPDATEREQUEST._serialized_end = 1125
    _ADDRESSUPDATERESPONSE._serialized_start = 1128
    _ADDRESSUPDATERESPONSE._serialized_end = 1289
    _ADDRESSDELETEREQUEST._serialized_start = 1291
    _ADDRESSDELETEREQUEST._serialized_end = 1402
    _ADDRESSDELETERESPONSE._serialized_start = 1404
    _ADDRESSDELETERESPONSE._serialized_end = 1502
    _ADDRESSESSERVICE._serialized_start = 1505
    _ADDRESSESSERVICE._serialized_end = 1940
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/warehouse_hierarchy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"v1/rules/warehouse_hierarchy.proto\x12-pro.omni.oms.api.v1.rules.warehouse_hierarchy\x1a\x11\x63ommon/base.proto\x1a\x18v1/rules/warehouse.proto\x1a\x17v1/rules/location.proto"\xbf\x02\n\x12WarehouseHierarchy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x44\n\x0cwarehouse_id\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x41\n\x0blocation_id\x18\t \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x19\n\x11quantity_security\x18\x04 \x01(\x02\x12\x10\n\x08sequence\x18\x05 \x01(\x05\x12\x16\n\x0esequence_order\x18\x06 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x07 \x01(\x08\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc9\x01\n\x1fWarehouseHierarchyCreateRequest\x12\x14\n\x0cwarehouse_id\x18\x01 \x01(\t\x12\x13\n\x0blocation_id\x18\x02 \x01(\t\x12\x19\n\x11quantity_security\x18\x03 \x01(\x02\x12\x10\n\x08sequence\x18\x04 \x01(\x05\x12\x16\n\x0esequence_order\x18\x05 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n WarehouseHierarchyCreateResponse\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfb\x02\n\x1dWarehouseHierarchyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x87\x02\n\x1eWarehouseHierarchyReadResponse\x12_\n\x14warehouses_hierarchy\x18\x01 \x03(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb9\x01\n\x1fWarehouseHierarchyUpdateRequest\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n WarehouseHierarchyUpdateResponse\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"e\n\x1fWarehouseHierarchyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"m\n WarehouseHierarchyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x95\x06\n\x19WarehouseHierarchyService\x12\xbd\x01\n\x18WarehouseHierarchyCreate\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyCreateRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyCreateResponse"\x00\x12\xb7\x01\n\x16WarehouseHierarchyRead\x12L.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyReadRequest\x1aM.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyReadResponse"\x00\x12\xbd\x01\n\x18WarehouseHierarchyUpdate\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyUpdateRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyUpdateResponse"\x00\x12\xbd\x01\n\x18WarehouseHierarchyDelete\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyDeleteRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.warehouse_hierarchy_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _WAREHOUSEHIERARCHY._serialized_start = 156
    _WAREHOUSEHIERARCHY._serialized_end = 475
    _WAREHOUSEHIERARCHYCREATEREQUEST._serialized_start = 478
    _WAREHOUSEHIERARCHYCREATEREQUEST._serialized_end = 679
    _WAREHOUSEHIERARCHYCREATERESPONSE._serialized_start = 682
    _WAREHOUSEHIERARCHYCREATERESPONSE._serialized_end = 887
    _WAREHOUSEHIERARCHYREADREQUEST._serialized_start = 890
    _WAREHOUSEHIERARCHYREADREQUEST._serialized_end = 1269
    _WAREHOUSEHIERARCHYREADRESPONSE._serialized_start = 1272
    _WAREHOUSEHIERARCHYREADRESPONSE._serialized_end = 1535
    _WAREHOUSEHIERARCHYUPDATEREQUEST._serialized_start = 1538
    _WAREHOUSEHIERARCHYUPDATEREQUEST._serialized_end = 1723
    _WAREHOUSEHIERARCHYUPDATERESPONSE._serialized_start = 1726
    _WAREHOUSEHIERARCHYUPDATERESPONSE._serialized_end = 1931
    _WAREHOUSEHIERARCHYDELETEREQUEST._serialized_start = 1933
    _WAREHOUSEHIERARCHYDELETEREQUEST._serialized_end = 2034
    _WAREHOUSEHIERARCHYDELETERESPONSE._serialized_start = 2036
    _WAREHOUSEHIERARCHYDELETERESPONSE._serialized_end = 2145
    _WAREHOUSEHIERARCHYSERVICE._serialized_start = 2148
    _WAREHOUSEHIERARCHYSERVICE._serialized_end = 2937
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/country.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import currency_pb2 as v1_dot_utilities_dot_currency__pb2
from omni.pro.protos.v1.utilities import document_type_pb2 as v1_dot_utilities_dot_document__type__pb2
from omni.pro.protos.v1.utilities import language_pb2 as v1_dot_utilities_dot_language__pb2
from omni.pro.protos.v1.utilities import territory_matrix_pb2 as v1_dot_utilities_dot_territory__matrix__pb2
from omni.pro.protos.v1.utilities import timezone_pb2 as v1_dot_utilities_dot_timezone__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/utilities/country.proto\x12%pro.omni.oms.api.v1.utilities.country\x1a\x11\x63ommon/base.proto\x1a\x1bv1/utilities/currency.proto\x1a v1/utilities/document_type.proto\x1a#v1/utilities/territory_matrix.proto\x1a\x1bv1/utilities/timezone.proto\x1a\x1bv1/utilities/language.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc1\x05\n\x07\x43ountry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11phone_number_size\x18\x04 \x01(\x05\x12\x14\n\x0cphone_prefix\x18\x05 \x01(\t\x12\x33\n\x0frequire_zipcode\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x08\x63urrency\x18\x07 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.currency.Currency\x12Q\n\x0e\x64ocument_types\x18\t \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType\x12[\n\x12territory_matrixes\x18\x0b \x03(\x0b\x32?.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrix\x12*\n\tmeta_data\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\ttimezones\x18\r \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.timezone.Timezone\x12\x43\n\tlanguages\x18\x0e \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.language.Language\x12\x11\n\tlow_level\x18\x0f \x01(\t\x12*\n\x06\x61\x63tive\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x11 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf1\x04\n\x14\x43ountryCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11phone_number_size\x18\x03 \x01(\x05\x12\x14\n\x0cphone_prefix\x18\x04 \x01(\t\x12\x17\n\x0frequire_zipcode\x18\x05 \x01(\x08\x12\x42\n\x08\x63urrency\x18\x06 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.currency.Currency\x12Q\n\x0e\x64ocument_types\x18\x08 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType\x12[\n\x12territory_matrixes\x18\n \x03(\x0b\x32?.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrix\x12*\n\tmeta_data\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\ttimezones\x18\x0c \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.timezone.Timezone\x12\x43\n\tlanguages\x18\r \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.language.Language\x12\x11\n\tlow_level\x18\x0e \x01(\t\x12\x36\n\x07\x63ontext\x18\x0f \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15\x43ountryCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07\x63ountry\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country"\xf0\x02\n\x12\x43ountryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xde\x01\n\x13\x43ountryReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x41\n\tcountries\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country"\x8f\x01\n\x14\x43ountryUpdateRequest\x12?\n\x07\x63ountry\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15\x43ountryUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07\x63ountry\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.utilities.country.Country"Z\n\x14\x43ountryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43ountryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc6\x04\n\x0e\x43ountryService\x12\x8c\x01\n\rCountryCreate\x12;.pro.omni.oms.api.v1.utilities.country.CountryCreateRequest\x1a<.pro.omni.oms.api.v1.utilities.country.CountryCreateResponse"\x00\x12\x86\x01\n\x0b\x43ountryRead\x12\x39.pro.omni.oms.api.v1.utilities.country.CountryReadRequest\x1a:.pro.omni.oms.api.v1.utilities.country.CountryReadResponse"\x00\x12\x8c\x01\n\rCountryUpdate\x12;.pro.omni.oms.api.v1.utilities.country.CountryUpdateRequest\x1a<.pro.omni.oms.api.v1.utilities.country.CountryUpdateResponse"\x00\x12\x8c\x01\n\rCountryDelete\x12;.pro.omni.oms.api.v1.utilities.country.CountryDeleteRequest\x1a<.pro.omni.oms.api.v1.utilities.country.CountryDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.country_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _COUNTRY._serialized_start = 309
    _COUNTRY._serialized_end = 1014
    _COUNTRYCREATEREQUEST._serialized_start = 1017
    _COUNTRYCREATEREQUEST._serialized_end = 1642
    _COUNTRYCREATERESPONSE._serialized_start = 1645
    _COUNTRYCREATERESPONSE._serialized_end = 1808
    _COUNTRYREADREQUEST._serialized_start = 1811
    _COUNTRYREADREQUEST._serialized_end = 2179
    _COUNTRYREADRESPONSE._serialized_start = 2182
    _COUNTRYREADRESPONSE._serialized_end = 2404
    _COUNTRYUPDATEREQUEST._serialized_start = 2407
    _COUNTRYUPDATEREQUEST._serialized_end = 2550
    _COUNTRYUPDATERESPONSE._serialized_start = 2553
    _COUNTRYUPDATERESPONSE._serialized_end = 2716
    _COUNTRYDELETEREQUEST._serialized_start = 2718
    _COUNTRYDELETEREQUEST._serialized_end = 2808
    _COUNTRYDELETERESPONSE._serialized_start = 2810
    _COUNTRYDELETERESPONSE._serialized_end = 2908
    _COUNTRYSERVICE._serialized_start = 2911
    _COUNTRYSERVICE._serialized_end = 3493
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_price_pb2 as v1_dot_rules_dot_delivery__price__pb2


class DeliveryPriceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryPriceCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceCreate",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateResponse.FromString,
        )
        self.DeliveryPriceRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceRead",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadResponse.FromString,
        )
        self.DeliveryPriceUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceUpdate",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateResponse.FromString,
        )
        self.DeliveryPriceDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceDelete",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteResponse.FromString,
        )


class DeliveryPriceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryPriceCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryPriceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryPriceCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceCreate,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateResponse.SerializeToString,
        ),
        "DeliveryPriceRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceRead,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadResponse.SerializeToString,
        ),
        "DeliveryPriceUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateResponse.SerializeToString,
        ),
        "DeliveryPriceDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceDelete,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryPriceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryPriceCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceCreate",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceRead",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceUpdate",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceDelete",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Location(_message.Message):
    __slots__ = [
        "active",
        "barcode",
        "code",
        "id",
        "name",
        "object_audit",
        "parent_id",
        "type_location",
        "warehouse_id",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    BARCODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    barcode: str
    code: str
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    parent_id: int
    type_location: str
    warehouse_id: int
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        parent_id: _Optional[int] = ...,
        code: _Optional[str] = ...,
        type_location: _Optional[str] = ...,
        barcode: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class LocationCreateRequest(_message.Message):
    __slots__ = ["active", "barcode", "code", "context", "name", "parent_id", "type_location", "warehouse_id"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    BARCODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    barcode: str
    code: str
    context: _base_pb2.Context
    name: str
    parent_id: int
    type_location: str
    warehouse_id: int
    def __init__(
        self,
        name: _Optional[str] = ...,
        parent_id: _Optional[int] = ...,
        code: _Optional[str] = ...,
        type_location: _Optional[str] = ...,
        barcode: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class LocationCreateResponse(_message.Message):
    __slots__ = ["location", "response_standard"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    location: Location
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        location: _Optional[_Union[Location, _Mapping]] = ...,
    ) -> None: ...

class LocationDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class LocationDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class LocationReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class LocationReadResponse(_message.Message):
    __slots__ = ["locations", "meta_data", "response_standard"]
    LOCATIONS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    locations: _containers.RepeatedCompositeFieldContainer[Location]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        locations: _Optional[_Iterable[_Union[Location, _Mapping]]] = ...,
    ) -> None: ...

class LocationUpdateRequest(_message.Message):
    __slots__ = ["context", "location"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    location: Location
    def __init__(
        self,
        location: _Optional[_Union[Location, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class LocationUpdateResponse(_message.Message):
    __slots__ = ["location", "response_standard"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    location: Location
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        location: _Optional[_Union[Location, _Mapping]] = ...,
    ) -> None: ...

class PickingType(_message.Message):
    __slots__ = [
        "active",
        "code",
        "default_location_dest_id",
        "default_location_src_id",
        "id",
        "name",
        "number_increment",
        "number_next_actual",
        "object_audit",
        "padding",
        "prefix",
        "return_picking_type_id",
        "sequence_code",
        "show_operations",
        "show_reserved",
        "warehouse_id",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_DEST_ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_SRC_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NUMBER_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    NUMBER_NEXT_ACTUAL_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PADDING_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    RETURN_PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_CODE_FIELD_NUMBER: _ClassVar[int]
    SHOW_OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    SHOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    code: str
    default_location_dest_id: int
    default_location_src_id: int
    id: int
    name: str
    number_increment: int
    number_next_actual: int
    object_audit: _base_pb2.ObjectAudit
    padding: int
    prefix: str
    return_picking_type_id: int
    sequence_code: str
    show_operations: _wrappers_pb2.BoolValue
    show_reserved: _wrappers_pb2.BoolValue
    warehouse_id: int
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        sequence_code: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        code: _Optional[str] = ...,
        return_picking_type_id: _Optional[int] = ...,
        show_operations: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        show_reserved: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        default_location_src_id: _Optional[int] = ...,
        default_location_dest_id: _Optional[int] = ...,
        prefix: _Optional[str] = ...,
        padding: _Optional[int] = ...,
        number_increment: _Optional[int] = ...,
        number_next_actual: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeCreateRequest(_message.Message):
    __slots__ = [
        "code",
        "context",
        "default_location_dest_id",
        "default_location_src_id",
        "name",
        "number_increment",
        "number_next_actual",
        "padding",
        "prefix",
        "return_picking_type_id",
        "sequence_code",
        "show_operations",
        "show_reserved",
        "warehouse_id",
    ]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_DEST_ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LOCATION_SRC_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NUMBER_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    NUMBER_NEXT_ACTUAL_FIELD_NUMBER: _ClassVar[int]
    PADDING_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    RETURN_PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_CODE_FIELD_NUMBER: _ClassVar[int]
    SHOW_OPERATIONS_FIELD_NUMBER: _ClassVar[int]
    SHOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    code: str
    context: _base_pb2.Context
    default_location_dest_id: int
    default_location_src_id: int
    name: str
    number_increment: int
    number_next_actual: int
    padding: int
    prefix: str
    return_picking_type_id: int
    sequence_code: str
    show_operations: _wrappers_pb2.BoolValue
    show_reserved: _wrappers_pb2.BoolValue
    warehouse_id: int
    def __init__(
        self,
        name: _Optional[str] = ...,
        sequence_code: _Optional[str] = ...,
        warehouse_id: _Optional[int] = ...,
        code: _Optional[str] = ...,
        return_picking_type_id: _Optional[int] = ...,
        show_operations: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        show_reserved: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        default_location_src_id: _Optional[int] = ...,
        default_location_dest_id: _Optional[int] = ...,
        prefix: _Optional[str] = ...,
        padding: _Optional[int] = ...,
        number_increment: _Optional[int] = ...,
        number_next_actual: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeCreateResponse(_message.Message):
    __slots__ = ["picking_type", "response_standard"]
    PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    picking_type: PickingType
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        picking_type: _Optional[_Union[PickingType, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class PickingTypeDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class PickingTypeReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeReadResponse(_message.Message):
    __slots__ = ["meta_data", "picking_types", "response_standard"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPES_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    picking_types: _containers.RepeatedCompositeFieldContainer[PickingType]
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        picking_types: _Optional[_Iterable[_Union[PickingType, _Mapping]]] = ...,
    ) -> None: ...

class PickingTypeUpdateRequest(_message.Message):
    __slots__ = ["context", "picking_type"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    picking_type: PickingType
    def __init__(
        self,
        picking_type: _Optional[_Union[PickingType, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class PickingTypeUpdateResponse(_message.Message):
    __slots__ = ["picking_type", "response_standard"]
    PICKING_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    picking_type: PickingType
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        picking_type: _Optional[_Union[PickingType, _Mapping]] = ...,
    ) -> None: ...

class Product(_message.Message):
    __slots__ = ["active", "id", "name", "object_audit", "product_doc_id", "template_doc_id"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    product_doc_id: str
    template_doc_id: str
    def __init__(
        self,
        id: _Optional[int] = ...,
        product_doc_id: _Optional[str] = ...,
        template_doc_id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class ProductCreateRequest(_message.Message):
    __slots__ = ["active", "context", "name", "product_doc_id", "template_doc_id"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    context: _base_pb2.Context
    name: str
    product_doc_id: str
    template_doc_id: str
    def __init__(
        self,
        product_doc_id: _Optional[str] = ...,
        template_doc_id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductCreateResponse(_message.Message):
    __slots__ = ["product", "response_standard"]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    product: Product
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product: _Optional[_Union[Product, _Mapping]] = ...,
    ) -> None: ...

class ProductDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ProductDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class ProductReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductReadResponse(_message.Message):
    __slots__ = ["meta_data", "products", "response_standard"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    PRODUCTS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    products: _containers.RepeatedCompositeFieldContainer[Product]
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        products: _Optional[_Iterable[_Union[Product, _Mapping]]] = ...,
    ) -> None: ...

class ProductUpdateRequest(_message.Message):
    __slots__ = ["context", "product"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    product: Product
    def __init__(
        self,
        product: _Optional[_Union[Product, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductUpdateResponse(_message.Message):
    __slots__ = ["product", "response_standard"]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    product: Product
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product: _Optional[_Union[Product, _Mapping]] = ...,
    ) -> None: ...

class Quant(_message.Message):
    __slots__ = [
        "active",
        "available_quantity",
        "id",
        "location_id",
        "lote",
        "object_audit",
        "product_id",
        "quantity",
        "uom_id",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOTE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    UOM_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    available_quantity: float
    id: int
    location_id: int
    lote: str
    object_audit: _base_pb2.ObjectAudit
    product_id: int
    quantity: float
    uom_id: int
    def __init__(
        self,
        id: _Optional[int] = ...,
        product_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        lote: _Optional[str] = ...,
        available_quantity: _Optional[float] = ...,
        quantity: _Optional[float] = ...,
        uom_id: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class QuantCreateRequest(_message.Message):
    __slots__ = ["available_quantity", "context", "location_id", "lote", "product_id", "quantity", "uom_id"]
    AVAILABLE_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOTE_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    UOM_ID_FIELD_NUMBER: _ClassVar[int]
    available_quantity: float
    context: _base_pb2.Context
    location_id: int
    lote: str
    product_id: int
    quantity: float
    uom_id: int
    def __init__(
        self,
        product_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        lote: _Optional[str] = ...,
        available_quantity: _Optional[float] = ...,
        quantity: _Optional[float] = ...,
        uom_id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QuantCreateResponse(_message.Message):
    __slots__ = ["quant", "response_standard"]
    QUANT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    quant: Quant
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        quant: _Optional[_Union[Quant, _Mapping]] = ...,
    ) -> None: ...

class QuantDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class QuantDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class QuantReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QuantReadResponse(_message.Message):
    __slots__ = ["meta_data", "quants", "response_standard"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    QUANTS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    quants: _containers.RepeatedCompositeFieldContainer[Quant]
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        quants: _Optional[_Iterable[_Union[Quant, _Mapping]]] = ...,
    ) -> None: ...

class QuantUpdateRequest(_message.Message):
    __slots__ = ["context", "quant"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    QUANT_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    quant: Quant
    def __init__(
        self,
        quant: _Optional[_Union[Quant, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QuantUpdateResponse(_message.Message):
    __slots__ = ["quant", "response_standard"]
    QUANT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    quant: Quant
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        quant: _Optional[_Union[Quant, _Mapping]] = ...,
    ) -> None: ...

class Route(_message.Message):
    __slots__ = [
        "active",
        "id",
        "name",
        "object_audit",
        "packing_selectable",
        "product_categ_selectable",
        "product_selectable",
        "sequence",
        "warehouse_id",
        "warehouse_selectable",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PACKING_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_CATEG_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    packing_selectable: _wrappers_pb2.BoolValue
    product_categ_selectable: _wrappers_pb2.BoolValue
    product_selectable: _wrappers_pb2.BoolValue
    sequence: int
    warehouse_id: int
    warehouse_selectable: _wrappers_pb2.BoolValue
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        sequence: _Optional[int] = ...,
        product_categ_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        product_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        packing_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        warehouse_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        warehouse_id: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class RouteCreateRequest(_message.Message):
    __slots__ = [
        "context",
        "name",
        "packing_selectable",
        "product_categ_selectable",
        "product_selectable",
        "sequence",
        "warehouse_id",
        "warehouse_selectable",
    ]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PACKING_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_CATEG_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_SELECTABLE_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    name: str
    packing_selectable: _wrappers_pb2.BoolValue
    product_categ_selectable: _wrappers_pb2.BoolValue
    product_selectable: _wrappers_pb2.BoolValue
    sequence: int
    warehouse_id: int
    warehouse_selectable: _wrappers_pb2.BoolValue
    def __init__(
        self,
        name: _Optional[str] = ...,
        sequence: _Optional[int] = ...,
        product_categ_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        product_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        packing_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        warehouse_selectable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        warehouse_id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RouteCreateResponse(_message.Message):
    __slots__ = ["response_standard", "route"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ROUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    route: Route
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        route: _Optional[_Union[Route, _Mapping]] = ...,
    ) -> None: ...

class RouteDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class RouteDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class RouteReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RouteReadResponse(_message.Message):
    __slots__ = ["meta_data", "response_standard", "routes"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ROUTES_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    routes: _containers.RepeatedCompositeFieldContainer[Route]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        routes: _Optional[_Iterable[_Union[Route, _Mapping]]] = ...,
    ) -> None: ...

class RouteUpdateRequest(_message.Message):
    __slots__ = ["context", "route"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ROUTE_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    route: Route
    def __init__(
        self,
        route: _Optional[_Union[Route, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RouteUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "route"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ROUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    route: Route
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        route: _Optional[_Union[Route, _Mapping]] = ...,
    ) -> None: ...

class Rule(_message.Message):
    __slots__ = [
        "action",
        "active",
        "id",
        "location_id",
        "location_src_id",
        "name",
        "object_audit",
        "picking_type_id",
        "procure_method",
        "route_id",
        "sequence",
        "warehouse_id",
    ]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_SRC_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    PROCURE_METHOD_FIELD_NUMBER: _ClassVar[int]
    ROUTE_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    action: str
    active: _wrappers_pb2.BoolValue
    id: int
    location_id: int
    location_src_id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    picking_type_id: int
    procure_method: str
    route_id: int
    sequence: int
    warehouse_id: int
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        action: _Optional[str] = ...,
        picking_type_id: _Optional[int] = ...,
        location_src_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        procure_method: _Optional[str] = ...,
        route_id: _Optional[int] = ...,
        warehouse_id: _Optional[int] = ...,
        sequence: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class RuleCreateRequest(_message.Message):
    __slots__ = [
        "action",
        "context",
        "location_id",
        "location_src_id",
        "name",
        "picking_type_id",
        "procure_method",
        "route_id",
        "sequence",
        "warehouse_id",
    ]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_SRC_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PICKING_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    PROCURE_METHOD_FIELD_NUMBER: _ClassVar[int]
    ROUTE_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    action: str
    context: _base_pb2.Context
    location_id: int
    location_src_id: int
    name: str
    picking_type_id: int
    procure_method: str
    route_id: int
    sequence: int
    warehouse_id: int
    def __init__(
        self,
        name: _Optional[str] = ...,
        action: _Optional[str] = ...,
        picking_type_id: _Optional[int] = ...,
        location_src_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        procure_method: _Optional[str] = ...,
        route_id: _Optional[int] = ...,
        warehouse_id: _Optional[int] = ...,
        sequence: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RuleCreateResponse(_message.Message):
    __slots__ = ["response_standard", "rule"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    RULE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    rule: Rule
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        rule: _Optional[_Union[Rule, _Mapping]] = ...,
    ) -> None: ...

class RuleDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class RuleDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class RuleReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RuleReadResponse(_message.Message):
    __slots__ = ["meta_data", "response_standard", "rules"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    rules: _containers.RepeatedCompositeFieldContainer[Rule]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        rules: _Optional[_Iterable[_Union[Rule, _Mapping]]] = ...,
    ) -> None: ...

class RuleUpdateRequest(_message.Message):
    __slots__ = ["context", "rule"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    RULE_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    rule: Rule
    def __init__(
        self,
        rule: _Optional[_Union[Rule, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class RuleUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "rule"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    RULE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    rule: Rule
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        rule: _Optional[_Union[Rule, _Mapping]] = ...,
    ) -> None: ...

class Uom(_message.Message):
    __slots__ = ["active", "code", "id", "name", "object_audit", "uom_doc_id"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    UOM_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    code: str
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    uom_doc_id: str
    def __init__(
        self,
        id: _Optional[int] = ...,
        uom_doc_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class UomCreateRequest(_message.Message):
    __slots__ = ["active", "code", "context", "name", "uom_doc_id"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    UOM_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    code: str
    context: _base_pb2.Context
    name: str
    uom_doc_id: str
    def __init__(
        self,
        uom_doc_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UomCreateResponse(_message.Message):
    __slots__ = ["response_standard", "uom"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    UOM_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    uom: Uom
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        uom: _Optional[_Union[Uom, _Mapping]] = ...,
    ) -> None: ...

class UomDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class UomDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class UomReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class UomReadResponse(_message.Message):
    __slots__ = ["meta_data", "response_standard", "uoms"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    UOMS_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    uoms: _containers.RepeatedCompositeFieldContainer[Uom]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        uoms: _Optional[_Iterable[_Union[Uom, _Mapping]]] = ...,
    ) -> None: ...

class UomUpdateRequest(_message.Message):
    __slots__ = ["context", "uom"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    UOM_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    uom: Uom
    def __init__(
        self, uom: _Optional[_Union[Uom, _Mapping]] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class UomUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "uom"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    UOM_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    uom: Uom
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        uom: _Optional[_Union[Uom, _Mapping]] = ...,
    ) -> None: ...

class Warehouse(_message.Message):
    __slots__ = [
        "active",
        "address",
        "code",
        "complement",
        "country_id",
        "id",
        "name",
        "object_audit",
        "territory_matrix_value",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    COMPLEMENT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIX_VALUE_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    address: str
    code: str
    complement: str
    country_id: int
    id: int
    name: str
    object_audit: _base_pb2.ObjectAudit
    territory_matrix_value: _struct_pb2.Struct
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        country_id: _Optional[int] = ...,
        territory_matrix_value: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        address: _Optional[str] = ...,
        complement: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class WarehouseCreateRequest(_message.Message):
    __slots__ = ["active", "address", "code", "complement", "context", "country_id", "name", "territory_matrix_value"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    COMPLEMENT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIX_VALUE_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    address: str
    code: str
    complement: str
    context: _base_pb2.Context
    country_id: int
    name: str
    territory_matrix_value: _struct_pb2.Struct
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        country_id: _Optional[int] = ...,
        territory_matrix_value: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        address: _Optional[str] = ...,
        complement: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseCreateResponse(_message.Message):
    __slots__ = ["response_standard", "warehouse"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    warehouse: Warehouse
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        warehouse: _Optional[_Union[Warehouse, _Mapping]] = ...,
    ) -> None: ...

class WarehouseDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: int
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class WarehouseDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class WarehouseReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: int
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseReadResponse(_message.Message):
    __slots__ = ["meta_data", "response_standard", "warehouses"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSES_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    warehouses: _containers.RepeatedCompositeFieldContainer[Warehouse]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        warehouses: _Optional[_Iterable[_Union[Warehouse, _Mapping]]] = ...,
    ) -> None: ...

class WarehouseUpdateRequest(_message.Message):
    __slots__ = ["context", "warehouse"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    warehouse: Warehouse
    def __init__(
        self,
        warehouse: _Optional[_Union[Warehouse, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "warehouse"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    warehouse: Warehouse
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        warehouse: _Optional[_Union[Warehouse, _Mapping]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/stock_move_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/stock/stock_move_line.proto\x12$pro.omni.oms.api.v1.stock.stock.line\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xfd\x02\n\rStockMoveLine\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x15\n\rstock_move_id\x18\x02 \x01(\x05\x12\x12\n\npicking_id\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\treference\x18\x05 \x01(\t\x12(\n\x04\x64\x61te\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x12\n\nproduct_id\x18\x08 \x01(\x05\x12\x13\n\x0blocation_id\x18\t \x01(\x05\x12\x18\n\x10location_dest_id\x18\n \x01(\x05\x12\x10\n\x08qty_done\x18\x0b \x01(\x05\x12\x16\n\x0eproduct_uom_id\x18\x0c \x01(\x05\x12*\n\x06\x61\x63tive\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc9\x02\n\x1aStockMoveLineCreateRequest\x12\x15\n\rstock_move_id\x18\x01 \x01(\x05\x12\x12\n\npicking_id\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x11\n\treference\x18\x04 \x01(\t\x12(\n\x04\x64\x61te\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x06 \x01(\t\x12\x12\n\nproduct_id\x18\x07 \x01(\x05\x12\x13\n\x0blocation_id\x18\x08 \x01(\x05\x12\x18\n\x10location_dest_id\x18\t \x01(\x05\x12\x10\n\x08qty_done\x18\n \x01(\x05\x12\x16\n\x0eproduct_uom_id\x18\x0b \x01(\x05\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb6\x01\n\x1bStockMoveLineCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12L\n\x0fstock_move_line\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.stock.line.StockMoveLine"\xf6\x02\n\x18StockMoveLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf0\x01\n\x19StockMoveLineReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12M\n\x10stock_move_lines\x18\x03 \x03(\x0b\x32\x33.pro.omni.oms.api.v1.stock.stock.line.StockMoveLine"\xa2\x01\n\x1aStockMoveLineUpdateRequest\x12L\n\x0fstock_move_line\x18\x01 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.stock.line.StockMoveLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb6\x01\n\x1bStockMoveLineUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12L\n\x0fstock_move_line\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.stock.line.StockMoveLine"`\n\x1aStockMoveLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"h\n\x1bStockMoveLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x84\x05\n\x14StockMoveLineService\x12\x9a\x01\n\x13StockMoveLineCreate\x12@.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineCreateRequest\x1a\x41.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineCreateResponse\x12\x94\x01\n\x11StockMoveLineRead\x12>.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineReadRequest\x1a?.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineReadResponse\x12\x9a\x01\n\x13StockMoveLineUpdate\x12@.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineUpdateRequest\x1a\x41.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineUpdateResponse\x12\x9a\x01\n\x13StockMoveLineDelete\x12@.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineDeleteRequest\x1a\x41.pro.omni.oms.api.v1.stock.stock.line.StockMoveLineDeleteResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.stock_move_line_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _STOCKMOVELINE._serialized_start = 157
    _STOCKMOVELINE._serialized_end = 538
    _STOCKMOVELINECREATEREQUEST._serialized_start = 541
    _STOCKMOVELINECREATEREQUEST._serialized_end = 870
    _STOCKMOVELINECREATERESPONSE._serialized_start = 873
    _STOCKMOVELINECREATERESPONSE._serialized_end = 1055
    _STOCKMOVELINEREADREQUEST._serialized_start = 1058
    _STOCKMOVELINEREADREQUEST._serialized_end = 1432
    _STOCKMOVELINEREADRESPONSE._serialized_start = 1435
    _STOCKMOVELINEREADRESPONSE._serialized_end = 1675
    _STOCKMOVELINEUPDATEREQUEST._serialized_start = 1678
    _STOCKMOVELINEUPDATEREQUEST._serialized_end = 1840
    _STOCKMOVELINEUPDATERESPONSE._serialized_start = 1843
    _STOCKMOVELINEUPDATERESPONSE._serialized_end = 2025
    _STOCKMOVELINEDELETEREQUEST._serialized_start = 2027
    _STOCKMOVELINEDELETEREQUEST._serialized_end = 2123
    _STOCKMOVELINEDELETERESPONSE._serialized_start = 2125
    _STOCKMOVELINEDELETERESPONSE._serialized_end = 2229
    _STOCKMOVELINESERVICE._serialized_start = 2232
    _STOCKMOVELINESERVICE._serialized_end = 2876
# @@protoc_insertion_point(module_scope)



# create a decorator to check if the user has permission to access the resource
from enum import Enum

from omni.pro.config import Config
from omni.pro.logger import LoggerTraceback, configure_logger
from omni.pro.protos.grpc_connector import Event, GRPClient
from omni.pro.protos.v1.users import user_pb2

logger = configure_logger(name=__name__)


class Permission(Enum):
    CAN_CREATE_ACCESS = "CAN_CREATE_ACCESS"
    CAN_UPDATE_ACCESS = "CAN_UPDATE_ACCESS"
    CAN_READ_ACCESS = "CAN_READ_ACCESS"
    CAN_DELETE_ACCESS = "CAN_DELETE_ACCESS"
    CAN_CREATE_ACTION = "CAN_CREATE_ACTION"
    CAN_READ_ACTION = "CAN_READ_ACTION"
    CAN_UPDATE_ACTION = "CAN_UPDATE_ACTION"
    CAN_DELETE_ACTION = "CAN_DELETE_ACTION"
    CAN_CREATE_GROUP = "CAN_CREATE_GROUP"
    CAN_READ_GROUP = "CAN_READ_GROUP"
    CAN_UPDATE_GROUP = "CAN_UPDATE_GROUP"
    CAN_DELETE_GROUP = "CAN_DELETE_GROUP"
    CAN_CREATE_USER = "CAN_CREATE_USER"
    CAN_UPDATE_USER = "CAN_UPDATE_USER"
    CAN_READ_USER = "CAN_READ_USER"
    CAN_DELETE_USER = "CAN_DELETE_USER"
    CAN_CHANGE_PASSWORD_USER = "CAN_CHAMGE_PASSWORD_USER"
    CAN_CHANGE_EMAIL_USER = "CAN_CHANGE_EMAIL_USER"


def permission_required(permission_name: Permission) -> callable:
    def decorador_func(funcion: callable) -> callable:
        def inner(instance, request, context):
            event = Event(
                module_grpc="v1.users.user_pb2_grpc",
                module_pb2="v1.users.user_pb2",
                stub_classname="UsersServiceStub",
                rpc_method="HasPermission",
                request_class="HasPermissionRequest",
                params={
                    "username": request.context.user,
                    "permission": permission_name.value,
                    "context": {"tenant": request.context.tenant},
                },
            )
            response: user_pb2.HasPermissionResponse = None
            response, success = GRPClient(Config.SAAS_MS_USER).call_rpc_fuction(event)
            if not success or not response.has_permission:
                raise Exception("User has no permission")
            c = funcion(instance, request, context)
            return c

        return inner

    return decorador_func


def sync_cognito_access(sync_allow_access):
    def decorador(funcion):
        def wrapper(*args, **kwargs):
            result = funcion(*args, **kwargs)
            sync_allow_access(result)
            return result

        return wrapper

    return decorador


# Definimos la función que queremos ejecutar al final
def sync_allow_access(result):
    try:
        logger.info("sync_allow_access")
        if isinstance(result, user_pb2.GroupCreateResponse):
            pass
    except Exception as e:
        LoggerTraceback.error("Resource Decorator exception", e, logger)
    return True



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/country.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x63ommon/country.proto\x12!pro.omni.oms.api.v1.stock.country\x1a\x11\x63ommon/base.proto"\x9a\x01\n\x07\x43ountry\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x16\n\x0e\x63ountry_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x82\x01\n\x14\x43ountryCreateRequest\x12\x16\n\x0e\x63ountry_doc_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43ountryCreateResponse\x12;\n\x07\x63ountry\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf0\x02\n\x12\x43ountryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xda\x01\n\x13\x43ountryReadResponse\x12=\n\tcountries\x18\x01 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x14\x43ountryUpdateRequest\x12;\n\x07\x63ountry\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43ountryUpdateResponse\x12;\n\x07\x63ountry\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"Z\n\x14\x43ountryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43ountryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa5\x04\n\x0e\x43ountryService\x12\x84\x01\n\rCountryCreate\x12\x37.pro.omni.oms.api.v1.stock.country.CountryCreateRequest\x1a\x38.pro.omni.oms.api.v1.stock.country.CountryCreateResponse"\x00\x12~\n\x0b\x43ountryRead\x12\x35.pro.omni.oms.api.v1.stock.country.CountryReadRequest\x1a\x36.pro.omni.oms.api.v1.stock.country.CountryReadResponse"\x00\x12\x84\x01\n\rCountryUpdate\x12\x37.pro.omni.oms.api.v1.stock.country.CountryUpdateRequest\x1a\x38.pro.omni.oms.api.v1.stock.country.CountryUpdateResponse"\x00\x12\x84\x01\n\rCountryDelete\x12\x37.pro.omni.oms.api.v1.stock.country.CountryDeleteRequest\x1a\x38.pro.omni.oms.api.v1.stock.country.CountryDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common.country_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _COUNTRY._serialized_start = 79
    _COUNTRY._serialized_end = 233
    _COUNTRYCREATEREQUEST._serialized_start = 236
    _COUNTRYCREATEREQUEST._serialized_end = 366
    _COUNTRYCREATERESPONSE._serialized_start = 369
    _COUNTRYCREATERESPONSE._serialized_end = 528
    _COUNTRYREADREQUEST._serialized_start = 531
    _COUNTRYREADREQUEST._serialized_end = 899
    _COUNTRYREADRESPONSE._serialized_start = 902
    _COUNTRYREADRESPONSE._serialized_end = 1120
    _COUNTRYUPDATEREQUEST._serialized_start = 1123
    _COUNTRYUPDATEREQUEST._serialized_end = 1262
    _COUNTRYUPDATERESPONSE._serialized_start = 1265
    _COUNTRYUPDATERESPONSE._serialized_end = 1424
    _COUNTRYDELETEREQUEST._serialized_start = 1426
    _COUNTRYDELETEREQUEST._serialized_end = 1516
    _COUNTRYDELETERESPONSE._serialized_start = 1518
    _COUNTRYDELETERESPONSE._serialized_end = 1616
    _COUNTRYSERVICE._serialized_start = 1619
    _COUNTRYSERVICE._serialized_end = 2168
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.utilities import currency_pb2 as _currency_pb2
from omni.pro.protos.v1.utilities import document_type_pb2 as _document_type_pb2
from omni.pro.protos.v1.utilities import language_pb2 as _language_pb2
from omni.pro.protos.v1.utilities import territory_matrix_pb2 as _territory_matrix_pb2
from omni.pro.protos.v1.utilities import timezone_pb2 as _timezone_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Country(_message.Message):
    __slots__ = [
        "active",
        "code",
        "currency",
        "document_types",
        "id",
        "languages",
        "low_level",
        "meta_data",
        "name",
        "object_audit",
        "phone_number_size",
        "phone_prefix",
        "require_zipcode",
        "territory_matrixes",
        "timezones",
    ]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    LOW_LEVEL_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_SIZE_FIELD_NUMBER: _ClassVar[int]
    PHONE_PREFIX_FIELD_NUMBER: _ClassVar[int]
    REQUIRE_ZIPCODE_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    TIMEZONES_FIELD_NUMBER: _ClassVar[int]
    active: _wrappers_pb2.BoolValue
    code: str
    currency: _currency_pb2.Currency
    document_types: _containers.RepeatedCompositeFieldContainer[_document_type_pb2.DocumentType]
    id: str
    languages: _containers.RepeatedCompositeFieldContainer[_language_pb2.Language]
    low_level: str
    meta_data: _struct_pb2.Struct
    name: str
    object_audit: _base_pb2.ObjectAudit
    phone_number_size: int
    phone_prefix: str
    require_zipcode: _wrappers_pb2.BoolValue
    territory_matrixes: _containers.RepeatedCompositeFieldContainer[_territory_matrix_pb2.TerritoryMatrix]
    timezones: _containers.RepeatedCompositeFieldContainer[_timezone_pb2.Timezone]
    def __init__(
        self,
        id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        phone_number_size: _Optional[int] = ...,
        phone_prefix: _Optional[str] = ...,
        require_zipcode: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        currency: _Optional[_Union[_currency_pb2.Currency, _Mapping]] = ...,
        document_types: _Optional[_Iterable[_Union[_document_type_pb2.DocumentType, _Mapping]]] = ...,
        territory_matrixes: _Optional[_Iterable[_Union[_territory_matrix_pb2.TerritoryMatrix, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        timezones: _Optional[_Iterable[_Union[_timezone_pb2.Timezone, _Mapping]]] = ...,
        languages: _Optional[_Iterable[_Union[_language_pb2.Language, _Mapping]]] = ...,
        low_level: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class CountryCreateRequest(_message.Message):
    __slots__ = [
        "code",
        "context",
        "currency",
        "document_types",
        "languages",
        "low_level",
        "meta_data",
        "name",
        "phone_number_size",
        "phone_prefix",
        "require_zipcode",
        "territory_matrixes",
        "timezones",
    ]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    LOW_LEVEL_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_SIZE_FIELD_NUMBER: _ClassVar[int]
    PHONE_PREFIX_FIELD_NUMBER: _ClassVar[int]
    REQUIRE_ZIPCODE_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    TIMEZONES_FIELD_NUMBER: _ClassVar[int]
    code: str
    context: _base_pb2.Context
    currency: _currency_pb2.Currency
    document_types: _containers.RepeatedCompositeFieldContainer[_document_type_pb2.DocumentType]
    languages: _containers.RepeatedCompositeFieldContainer[_language_pb2.Language]
    low_level: str
    meta_data: _struct_pb2.Struct
    name: str
    phone_number_size: int
    phone_prefix: str
    require_zipcode: bool
    territory_matrixes: _containers.RepeatedCompositeFieldContainer[_territory_matrix_pb2.TerritoryMatrix]
    timezones: _containers.RepeatedCompositeFieldContainer[_timezone_pb2.Timezone]
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        phone_number_size: _Optional[int] = ...,
        phone_prefix: _Optional[str] = ...,
        require_zipcode: bool = ...,
        currency: _Optional[_Union[_currency_pb2.Currency, _Mapping]] = ...,
        document_types: _Optional[_Iterable[_Union[_document_type_pb2.DocumentType, _Mapping]]] = ...,
        territory_matrixes: _Optional[_Iterable[_Union[_territory_matrix_pb2.TerritoryMatrix, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        timezones: _Optional[_Iterable[_Union[_timezone_pb2.Timezone, _Mapping]]] = ...,
        languages: _Optional[_Iterable[_Union[_language_pb2.Language, _Mapping]]] = ...,
        low_level: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CountryCreateResponse(_message.Message):
    __slots__ = ["country", "response_standard"]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    country: Country
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        country: _Optional[_Union[Country, _Mapping]] = ...,
    ) -> None: ...

class CountryDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: str
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class CountryDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class CountryReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: str
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CountryReadResponse(_message.Message):
    __slots__ = ["countries", "meta_data", "response_standard"]
    COUNTRIES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    countries: _containers.RepeatedCompositeFieldContainer[Country]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        countries: _Optional[_Iterable[_Union[Country, _Mapping]]] = ...,
    ) -> None: ...

class CountryUpdateRequest(_message.Message):
    __slots__ = ["context", "country"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    country: Country
    def __init__(
        self,
        country: _Optional[_Union[Country, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CountryUpdateResponse(_message.Message):
    __slots__ = ["country", "response_standard"]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    country: Country
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        country: _Optional[_Union[Country, _Mapping]] = ...,
    ) -> None: ...



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import calendar_pb2 as _calendar_pb2
from omni.pro.protos.v1.rules import schedule_work_line_pb2 as _schedule_work_line_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleWork(_message.Message):
    __slots__ = ["active", "calendar_id", "id", "name", "object_audit", "schedule_work_line_ids"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CALENDAR_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_WORK_LINE_IDS_FIELD_NUMBER: _ClassVar[int]
    active: bool
    calendar_id: _calendar_pb2.Calendar
    id: str
    name: str
    object_audit: _base_pb2.ObjectAudit
    schedule_work_line_ids: _containers.RepeatedCompositeFieldContainer[_schedule_work_line_pb2.ScheduleWorkLine]
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        calendar_id: _Optional[_Union[_calendar_pb2.Calendar, _Mapping]] = ...,
        schedule_work_line_ids: _Optional[_Iterable[_Union[_schedule_work_line_pb2.ScheduleWorkLine, _Mapping]]] = ...,
        active: bool = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class ScheduleWorkCreateRequest(_message.Message):
    __slots__ = ["calendar_id", "context", "name", "schedule_work_line_ids"]
    CALENDAR_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_WORK_LINE_IDS_FIELD_NUMBER: _ClassVar[int]
    calendar_id: str
    context: _base_pb2.Context
    name: str
    schedule_work_line_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        name: _Optional[str] = ...,
        calendar_id: _Optional[str] = ...,
        schedule_work_line_ids: _Optional[_Iterable[str]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ScheduleWorkCreateResponse(_message.Message):
    __slots__ = ["response_standard", "schedule_work"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_WORK_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    schedule_work: ScheduleWork
    def __init__(
        self,
        schedule_work: _Optional[_Union[ScheduleWork, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class ScheduleWorkDeleteRequest(_message.Message):
    __slots__ = ["context", "id"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    id: str
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ScheduleWorkDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class ScheduleWorkReadRequest(_message.Message):
    __slots__ = ["context", "fields", "filter", "group_by", "id", "paginated", "sort_by"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    id: str
    paginated: _base_pb2.Paginated
    sort_by: _base_pb2.SortBy
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ScheduleWorkReadResponse(_message.Message):
    __slots__ = ["meta_data", "response_standard", "schedules_work"]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    SCHEDULES_WORK_FIELD_NUMBER: _ClassVar[int]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    schedules_work: _containers.RepeatedCompositeFieldContainer[ScheduleWork]
    def __init__(
        self,
        schedules_work: _Optional[_Iterable[_Union[ScheduleWork, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class ScheduleWorkUpdateRequest(_message.Message):
    __slots__ = ["context", "schedule_work"]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_WORK_FIELD_NUMBER: _ClassVar[int]
    context: _base_pb2.Context
    schedule_work: ScheduleWork
    def __init__(
        self,
        schedule_work: _Optional[_Union[ScheduleWork, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ScheduleWorkUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "schedule_work"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_WORK_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    schedule_work: ScheduleWork
    def __init__(
        self,
        schedule_work: _Optional[_Union[ScheduleWork, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...
